==> sleepanalyser_1.5-100.tar.gz: sleepanalyser-1.5/src/opt/SleepAnalyser/myFunctions.py <==
import sys
import os
import random
import time
from time import strftime
import math
import array
import string

import ConfigParser
import os, os.path

import data
from myFunctions2 import * #Own functions


###########################################################################
# Function to open or close the log file
###########################################################################
def StartLogfile(interval):       
    #if not on the N900, use another place for the log file 
    if(data.demo==1): data.logfolder=data.devlogfolder #folder on devel PC
    else: data.logfolder=data.defaultlogfolder
    
    print "Logfolder:",  data.logfolder
    if(not os.path.exists(data.logfolder)): #create log folder
        try:
            os.mkdir(data.logfolder)
        except:
            print "Failed to create logfolder!"
        
    
    #open file, write header
#    data.StartTime=time.localtime()
#    data.StartTimeSec=time.mktime(data.StartTime)
    t=strftime("%Y-%m-%d_%H-%M-%S", data.StartTime)
    data.logfilename="SleepAnalyser_"+t+".csv"
    data.logfile = open(data.logfolder+data.logfilename, 'w')
    print "Created logfile "+data.logfilename
    t="Time, AccX, AccY, "
    d=strftime("%d-%m-%Y", data.StartTime)
    data.Header=t+"User: "+data.user+", SW version: "+data.version+", Date: " + d + \
            ", Sampling interval: " + str(interval)+" ms, sampling smoothing: " +str(data.sample_smoothing)+ \
            ", value_smoothing: " + str(data.sample_smoothing )
    if(data.AlarmIsSet==True): #only add alarm data if an alarm is set
        data.Header=data.Header+", Alarm: "+data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute)+", Alarm Time Window: "+str(data.AlarmTimeWindow)
    data.Header=data.Header+"\n"
    data.logfile.write(data.Header)
    data.logfile.write("Note: \n")









###########################################################################
#  Write data into file, so it can be used in other tools
###########################################################################
def WriteIntoLogFile():
    d=str(data.arrData[0][data.arrDataIndex]) + ", " +  \
        str(data.arrData[1][data.arrDataIndex]) + ", " +  \
        str(data.arrData[2][data.arrDataIndex]) + ", " +  \
        str(data.arrData[5][data.arrDataIndex])

    data.logfile.write(d+"\n")
    if(data.debug==1): print d



###########################################################################
#  Close log file
###########################################################################
def StopLogfile():    
    data.logfile.close()



###########################################################################
#  Load list of log files into array
###########################################################################
def LoadFileList():
    Show_passed_time("LoadFileList Start")
    print "Load list of all csv files in folder:",  data.logfolder
    output = os.popen("cd "+str(data.logfolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
    data.arrLogFiles=output.split("\n")
    data.arrLogFiles.pop()
    if(data.debug==1): print data.arrLogFiles
    if(data.logfilename>""):
        if(data.debug==1): print data.logfilename
        data.arrLogFileIndex=0
        for i in range(len(data.arrLogFiles)):
            if(data.logfilename==data.arrLogFiles[i]): data.arrLogFileIndex=i
            
    Show_passed_time("LoadFileList End")






###########################################################################
#  Load log file  to read and visualise it
###########################################################################
def OpenLogFile():    
#    Show_passed_time("OpenLogFile Start")

    for i in range(0, data.arrDataLen): #clear data of old records
        for j in range(0,  6): data.arrData[j][i]=0
        
    data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
    print "Open Log file:",  data.logfolder+data.logfilename
    
    if(not os.path.exists(data.logfolder)): #create log folder (dirty workaround for if folder is not existing
        os.mkdir(data.logfolder)
        data.lastlogfile=""

    f=data.logfolder+data.logfilename
    if(not os.path.exists(f) or data.logfilename==""): return 2 #selected file or folder does not exist 
    file = open(f, 'r')
    data.arrDataIndex=0
    ret=0
    try:
        data.Header=file.readline()
#        if(data.debug==1): 
        print "Header:",  data.Header
        h=string.split(data.Header, ", ")
        x=h[4] #SW version
        SWversion=string.replace(x, "SW version:",  "")
        try:
            fl=float(SWversion)
        except:
            print "SW Version format not valid:",  SWversion
            fl=0.0
#        print x,  fl,  data.version
        if(fl>1.1 and fl!=213.1321): #log files newer than SW version 1.1. and not Demo version have a new line with notes
#            print "SW version > 1.1, contains Note"
            data.Note=file.readline()
            data.Note=string.replace(data.Note, "Note: ",  "")
            data.Note=string.replace(data.Note, "\n",  "")
        else:
            data.Note=""
            data.Header=string.replace(data.Header,  x,  "SW version: "+str(data.version))
#            print "New header:",  data.Header
        if(data.debug==1): print "Note:",  data.Note
            
            
        x=h[5] #Date
        data.StartDate=string.replace(x, "Date: ",  "")
        
        
        x=h[6] #Interval
        t=string.replace(x, "Sampling interval: ",  "")
        data.interval=int(string.replace(t, " ms",  ""))
        
        x=h[8] #value_smoothing
        data.value_smoothing=int(string.replace(x, "value_smoothing: ",  ""))
        
        print "Interval:",  data.interval,  ", value_smoothing:",  data.value_smoothing
        
            
        if(len(h)>10):  #header includes Alarm data 
            x=h[9] #get the set Alarm time
            t=string.replace(x, "Alarm: ",  "")
            t=string.split(t, " ")
            data.AlarmDate=t[0]
            t=string.split(t[1], ":") #time
            data.AlarmHour=int(t[0])
            data.AlarmMinute=int(t[1])            
            
            x=h[10] #get the set AlarmTimeWindow
            t=string.replace(x, "Alarm Time Window: ",  "")
#            t=string.split(t, ":")
            data.AlarmTimeWindow=int(t)

            data.DelayStartTime=0 #needed?
            data.AlarmTimeSec=time.mktime(time.strptime(data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute), "%d-%m-%Y %H:%M"))
            
            print "Header Alarm time:",  data.AlarmHour,  ":",  data.AlarmMinute,  "AlarmTimeWindow:",  data.AlarmTimeWindow
            data.AlarmIsSet=True
        else:
#            data.AlarmHour=-1
#            data.AlarmMinute=-1      
            data.AlarmIsSet=False
            
            
        
            
            
            
            
            
        Show_passed_time("OpenLogFile: Opened file, loaded header data")
            
            
        #load main data
        data.MidnightTransitions=0
        try:
            for line in file:
    #            print line
                d=string.split(line[:-1],  ", ")
#                print len(d)
                data.arrData[0][data.arrDataIndex]=d[0] #time
                data.arrData[1][data.arrDataIndex]=int(d[1]) #X
                data.arrData[2][data.arrDataIndex]=int(d[2]) #Y
                try:
#                    print len(d),  d[0],  d[1],  d[2],  d[3]
                    if(len(d)>2):
                        data.arrData[5][data.arrDataIndex]=d[3] #Event
    #                    print len(d),  d[0],  d[1],  d[2],  d[3],  "----",  data.arrDataIndex,  data.arrData[5][data.arrDataIndex]
                except:
                    pass
                    
                
                if(data.arrDataIndex>0): #check for transitions beond midnight:
                    if(data.arrData[0][data.arrDataIndex][:2]=="00"):
                        if(data.arrData[0][data.arrDataIndex-1][:2]=="23"): data.MidnightTransitions=data.MidnightTransitions+1                
                data.arrDataIndex=data.arrDataIndex+1            
                if(data.arrDataIndex==data.arrDataLen-1): 
                    print "Stopped, array is full, file is to big: ",  data.arrDataIndex,  "Lines"
                    file.close()
                    return 1 #File to long
                    break
        except:
            print "File is corrupted"
            file.close()
            data.arrDataIndex=0
            return 3 #corrupted file
    finally:
        file.close()
    
    print "Loaded",  str(data.arrDataIndex),  "lines"
    
    if(data.arrDataIndex==0):
        print "No Data in file"
        return 4
    else:
        data.StartTimeSec=time.mktime(time.strptime(data.StartDate+" "+str(data.arrData[0][0]), "%d-%m-%Y %H:%M:%S"))

        
    Show_passed_time("OpenLogFile End")
    return 0
    
    
    
    
###########################################################################
#  Load log file  to change Note (on line 2)
###########################################################################
def ChangeNoteInFile():    
#    print "Reopen log file and update note:",  data.Note
    file = open(data.logfolder+data.logfilename, 'w')
    print "Open logfile",  data.logfilename,  ", change Note to \"",  data.Note,  "\" in file",  data.logfilename

    file.write(data.Header)
    file.write("Note: "+data.Note+"\n")
    i=0
    for i in range(0,  data.arrDataIndex):
        d=str(data.arrData[0][i]) + ", " + str(data.arrData[1][i]) + ", " +  str(data.arrData[2][i]) + ", " +  str(data.arrData[5][i])
        file.write(d+"\n")
    file.close()
    print "Wrote",  i +1,  "lines into file"
    
    
    
    
###########################################################################
# Load the configuration from the config file
###########################################################################
def LoadConfig():    
    #get configuration
    global config
    print "Configuration file:",  data.configfolder+data.ConfigFile
    config = ConfigParser.SafeConfigParser()
#    if os.path.exists(data.configfolder+data.ConfigFile):
    try:
        config.read(data.configfolder+data.ConfigFile)
        
        data.sampling = config.getint('main', 'sampling')
        data.sample_smoothing = config.getint('main', 'sample_smoothing')
        data.value_smoothing = config.getint('main', 'value_smoothing')
        data.trigger = config.getint('main', 'trigger')
        data.derivation = config.getint('main', 'derivation')
        data.Ysize = config.getint('main', 'Ysize')
        data.Xscale = config.getint('main', 'Xscale')
        data.Yscale = config.getint('main', 'Yscale')
        data.user = config.get('main', 'user')
        data.lastlogfile = config.get('main', 'lastlogfile')
        data.OfflineMode = config.get('main', 'OfflineMode')
        data.DelayStartTime = config.getint('main', 'DelayStartTime')
        data.AlarmHour = config.getint('main', 'AlarmHour')
        data.AlarmMinute = config.getint('main', 'AlarmMinute')
        data.AlarmTimeWindow = config.getint('main', 'AlarmTimeWindow')
        print "Configuration loaded ("+data.ConfigFile+")"
#    else:
    except: #use default config
        print data.configfolder+data.ConfigFile + " not existing or not read properly, using default parameters..."
        try:
            config.add_section('main')
        except:
            pass
        config.set('main', 'sampling', str(data.sampling))
        config.set('main', 'sample_smoothing', str(data.sample_smoothing))      
        config.set('main', 'value_smoothing', str(data.value_smoothing))      
        config.set('main', 'trigger', str(data.trigger))      
        config.set('main', 'derivation', str(data.derivation))      
        config.set('main', 'Ysize', str(data.Ysize))      
        config.set('main', 'Xscale', str(data.Xscale))     
        config.set('main', 'Yscale', str(data.Yscale))      
        config.set('main', 'user', str(data.user))      
        config.set('main', 'lastlogfile', str(data.lastlogfile))    
        config.set('main', 'OfflineMode', str(data.OfflineMode))      
        config.set('main', 'DelayStartTime', str(data.DelayStartTime))    
        config.set('main', 'AlarmHour', str(data.AlarmHour))    
        config.set('main', 'AlarmMinute', str(data.AlarmMinute))    
        config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))    

    return config



###########################################################################
# Write the configuration into the config file
###########################################################################
def WriteConfig():    
        global config
        config.set('main', 'trigger', str(data.trigger))  
        
        f=data.configfolder+data.ConfigFile
        print "Save configuration ("+f+")"
        if (not os.path.exists(data.configfolder)):
            print "Create configuration folder: ",  data.configfolder
            os.mkdir(data.configfolder)
        try:
            data.configfile = open(f, 'w')
            config.write(data.configfile)
            print "Configuration saved"
        except:
            print "Failed to write configuration file!"

==> sleepanalyser_1.5-101.tar.gz: sleepanalyser-1.5/src/opt/SleepAnalyser/myFunctions.py <==
import sys
import os
import random
import time
from time import strftime
import math
import array
import string

import ConfigParser
import os, os.path

import data
from myFunctions2 import * #Own functions


###########################################################################
# Function to open or close the log file
###########################################################################
def StartLogfile(interval):       
    #if not on the N900, use another place for the log file 
    if(data.demo==1): data.logfolder=data.devlogfolder #folder on devel PC
    else: data.logfolder=data.defaultlogfolder
    
    print "Logfolder:",  data.logfolder
    if(not os.path.exists(data.logfolder)): #create log folder
        try:
            os.mkdir(data.logfolder)
        except:
            print "Failed to create logfolder!"
        
    
    #open file, write header
#    data.StartTime=time.localtime()
#    data.StartTimeSec=time.mktime(data.StartTime)
    t=strftime("%Y-%m-%d_%H-%M-%S", data.StartTime)
    data.logfilename="SleepAnalyser_"+t+".csv"
    data.logfile = open(data.logfolder+data.logfilename, 'w')
    print "Created logfile "+data.logfilename
    t="Time, AccX, AccY, "
    d=strftime("%d-%m-%Y", data.StartTime)
    data.Header=t+"User: "+data.user+", SW version: "+data.version+", Date: " + d + \
            ", Sampling interval: " + str(interval)+" ms, sampling smoothing: " +str(data.sample_smoothing)+ \
            ", value_smoothing: " + str(data.sample_smoothing )
    if(data.AlarmIsSet==True): #only add alarm data if an alarm is set
        data.Header=data.Header+", Alarm: "+data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute)+", Alarm Time Window: "+str(data.AlarmTimeWindow)
    data.Header=data.Header+"\n"
    data.logfile.write(data.Header)
    data.logfile.write("Note: \n")









###########################################################################
#  Write data into file, so it can be used in other tools
###########################################################################
def WriteIntoLogFile():
    d=str(data.arrData[0][data.arrDataIndex]) + ", " +  \
        str(data.arrData[1][data.arrDataIndex]) + ", " +  \
        str(data.arrData[2][data.arrDataIndex]) + ", " +  \
        str(data.arrData[5][data.arrDataIndex])

    data.logfile.write(d+"\n")
    if(data.debug==1): print d



###########################################################################
#  Close log file
###########################################################################
def StopLogfile():    
    data.logfile.close()



###########################################################################
#  Load list of log files into array
###########################################################################
def LoadFileList():
    Show_passed_time("LoadFileList Start")
    print "Load list of all csv files in folder:",  data.logfolder
    output = os.popen("cd "+str(data.logfolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
    data.arrLogFiles=output.split("\n")
    data.arrLogFiles.pop()
    if(data.debug==1): print data.arrLogFiles
    if(data.logfilename>""):
        if(data.debug==1): print data.logfilename
        data.arrLogFileIndex=0
        for i in range(len(data.arrLogFiles)):
            if(data.logfilename==data.arrLogFiles[i]): data.arrLogFileIndex=i
            
    Show_passed_time("LoadFileList End")






###########################################################################
#  Load log file  to read and visualise it
###########################################################################
def LoadLogFile():    
#    Show_passed_time("LoadLogFile Start")

    for i in range(0, data.arrDataLen): #clear data of old records
        for j in range(0,  6): data.arrData[j][i]=0
        
    data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
    print "Open Log file:",  data.logfolder+data.logfilename
    
    if(not os.path.exists(data.logfolder)): #create log folder (dirty workaround for if folder is not existing
        os.mkdir(data.logfolder)
        data.lastlogfile=""

    f=data.logfolder+data.logfilename
    if(not os.path.exists(f) or data.logfilename==""): return 2 #selected file or folder does not exist 
    file = open(f, 'r')
    data.arrDataIndex=0
    ret=0
    try:
        data.Header=file.readline()
#        if(data.debug==1): 
        print "Header:",  data.Header
        h=string.split(data.Header, ", ")
        x=h[4] #SW version
        SWversion=string.replace(x, "SW version:",  "")
        try:
            fl=float(SWversion)
        except:
            print "SW Version format not valid:",  SWversion
            fl=0.0
#        print x,  fl,  data.version
        if(fl>1.1 and fl!=213.1321): #log files newer than SW version 1.1. and not Demo version have a new line with notes
#            print "SW version > 1.1, contains Note"
            try:
                data.Note=file.readline()
                data.Note=string.replace(data.Note, "Note: ",  "")
                data.Note=string.replace(data.Note, "\n",  "")
            except:
                pass
        else:
            data.Note=""
            data.Header=string.replace(data.Header,  x,  "SW version: "+str(data.version))
#            print "New header:",  data.Header
        if(data.debug==1): print "Note:",  data.Note
            
            
        x=h[5] #Date
        data.StartDate=string.replace(x, "Date: ",  "")
        
        
        x=h[6] #Interval
        t=string.replace(x, "Sampling interval: ",  "")
        data.interval=int(string.replace(t, " ms",  ""))
        
        x=h[8] #value_smoothing
        data.value_smoothing=int(string.replace(x, "value_smoothing: ",  ""))
        
        print "Interval:",  data.interval,  ", value_smoothing:",  data.value_smoothing
        
            
        if(len(h)>10):  #header includes Alarm data 
            x=h[9] #get the set Alarm time
            t=string.replace(x, "Alarm: ",  "")
            t=string.split(t, " ")
            data.AlarmDate=t[0]
            t=string.split(t[1], ":") #time
            data.AlarmHour=int(t[0])
            data.AlarmMinute=int(t[1])            
            
            x=h[10] #get the set AlarmTimeWindow
            t=string.replace(x, "Alarm Time Window: ",  "")
#            t=string.split(t, ":")
            data.AlarmTimeWindow=int(t)

            data.DelayStartTime=0 #needed?
            data.AlarmTimeSec=time.mktime(time.strptime(data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute), "%d-%m-%Y %H:%M"))
            
            print "Header Alarm time:",  data.AlarmHour,  ":",  data.AlarmMinute,  "AlarmTimeWindow:",  data.AlarmTimeWindow
            data.AlarmIsSet=True
        else:
#            data.AlarmHour=-1
#            data.AlarmMinute=-1      
            data.AlarmIsSet=False
            
            
        
            
            
            
            
            
        Show_passed_time("LoadLogFile: Opened file, loaded header data")
            
            
        #load main data
        data.MidnightTransitions=0
        try:
            for line in file:
    #            print line
                d=string.split(line[:-1],  ", ")
#                print len(d)
                data.arrData[0][data.arrDataIndex]=d[0] #time
                data.arrData[1][data.arrDataIndex]=int(d[1]) #X
                data.arrData[2][data.arrDataIndex]=int(d[2]) #Y
                try:
#                    print len(d),  d[0],  d[1],  d[2],  d[3]
                    if(len(d)>2):
                        data.arrData[5][data.arrDataIndex]=d[3] #Event
    #                    print len(d),  d[0],  d[1],  d[2],  d[3],  "----",  data.arrDataIndex,  data.arrData[5][data.arrDataIndex]
                except:
                    pass
                    
                
                if(data.arrDataIndex>0): #check for transitions beond midnight:
                    if(data.arrData[0][data.arrDataIndex][:2]=="00"):
                        if(data.arrData[0][data.arrDataIndex-1][:2]=="23"): data.MidnightTransitions=data.MidnightTransitions+1                
                data.arrDataIndex=data.arrDataIndex+1            
                if(data.arrDataIndex==data.arrDataLen-1): 
                    print "Stopped, array is full, file is to big: ",  data.arrDataIndex,  "Lines"
                    file.close()
                    return 1 #File to long
                    break
        except:
            print "File is corrupted"
            file.close()
            data.arrDataIndex=0
            return 3 #corrupted file
    finally:
        file.close()
    
    print "Loaded",  str(data.arrDataIndex),  "lines"
    
    if(data.arrDataIndex==0):
        print "No Data in file"
        return 4
    else:
        data.StartTimeSec=time.mktime(time.strptime(data.StartDate+" "+str(data.arrData[0][0]), "%d-%m-%Y %H:%M:%S"))

        
    Show_passed_time("LoadLogFile End")
    return 0
    
    
    
    
###########################################################################
#  Load log file  to change Note (on line 2)
###########################################################################
def ChangeNoteInFile():    
#    print "Reopen log file and update note:",  data.Note
    file = open(data.logfolder+data.logfilename, 'w')
    print "Open logfile",  data.logfilename,  ", change Note to \"",  data.Note,  "\" in file",  data.logfilename

    file.write(data.Header)
    file.write("Note: "+data.Note+"\n")
    i=0
    for i in range(0,  data.arrDataIndex):
        d=str(data.arrData[0][i]) + ", " + str(data.arrData[1][i]) + ", " +  str(data.arrData[2][i]) + ", " +  str(data.arrData[5][i])
        file.write(d+"\n")
    file.close()
    print "Wrote",  i +1,  "lines into file"
    
    
    
    
###########################################################################
# Load the configuration from the config file
###########################################################################
def LoadConfig():    
    #get configuration
    global config
    print "Configuration file:",  data.configfolder+data.ConfigFile
    config = ConfigParser.SafeConfigParser()
#    if os.path.exists(data.configfolder+data.ConfigFile):
    try:
        config.read(data.configfolder+data.ConfigFile)
        
        data.sampling = config.getint('main', 'sampling')
        data.sample_smoothing = config.getint('main', 'sample_smoothing')
        data.value_smoothing = config.getint('main', 'value_smoothing')
        data.trigger = config.getint('main', 'trigger')
        data.derivation = config.getint('main', 'derivation')
        data.Ysize = config.getint('main', 'Ysize')
        data.Xscale = config.getint('main', 'Xscale')
        data.Yscale = config.getint('main', 'Yscale')
        data.user = config.get('main', 'user')
        data.lastlogfile = config.get('main', 'lastlogfile')
        data.OfflineMode = config.get('main', 'OfflineMode')
        data.DelayStartTime = config.getint('main', 'DelayStartTime')
        data.AlarmHour = config.getint('main', 'AlarmHour')
        data.AlarmMinute = config.getint('main', 'AlarmMinute')
        data.AlarmTimeWindow = config.getint('main', 'AlarmTimeWindow')
        print "Configuration loaded ("+data.ConfigFile+")"
#    else:
    except: #use default config
        print data.configfolder+data.ConfigFile + " not existing or not read properly, using default parameters..."
        try:
            config.add_section('main')
        except:
            pass
        config.set('main', 'sampling', str(data.sampling))
        config.set('main', 'sample_smoothing', str(data.sample_smoothing))      
        config.set('main', 'value_smoothing', str(data.value_smoothing))      
        config.set('main', 'trigger', str(data.trigger))      
        config.set('main', 'derivation', str(data.derivation))      
        config.set('main', 'Ysize', str(data.Ysize))      
        config.set('main', 'Xscale', str(data.Xscale))     
        config.set('main', 'Yscale', str(data.Yscale))      
        config.set('main', 'user', str(data.user))      
        config.set('main', 'lastlogfile', str(data.lastlogfile))    
        config.set('main', 'OfflineMode', str(data.OfflineMode))      
        config.set('main', 'DelayStartTime', str(data.DelayStartTime))    
        config.set('main', 'AlarmHour', str(data.AlarmHour))    
        config.set('main', 'AlarmMinute', str(data.AlarmMinute))    
        config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))    

    return config



###########################################################################
# Write the configuration into the config file
###########################################################################
def WriteConfig():    
        global config
        config.set('main', 'trigger', str(data.trigger))  
        
        f=data.configfolder+data.ConfigFile
        print "Save configuration ("+f+")"
        if (not os.path.exists(data.configfolder)):
            print "Create configuration folder: ",  data.configfolder
            os.mkdir(data.configfolder)
        try:
            data.configfile = open(f, 'w')
            config.write(data.configfile)
            print "Configuration saved"
        except:
            print "Failed to write configuration file!"
